.. Problem Solving with Algorithms and Data Structures documentation master file, created by
   sphinx-quickstart on Thu Oct 27 08:17:45 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. meta::
   :description: An interactive version of Problem Solving with Algorithms and Data Structures using Python.
   :keywords: python, data structures, computer science

.. toc_version: 2

================================================================
Problem Solving with Algorithms and Data Structures using Python
================================================================

.. image:: _static/PythonDScover.jpg
    :alt: PythonDS Cover

By Brad Miller and David Ranum, Luther College

.. raw:: html

   <ul>
   <li><a href="/runestone/assignments/chooseAssignment.html">Assignments</a></li>
   </ul>

There is a wonderful `collection of YouTube videos <https://www.youtube.com/user/gjenkinslbcc>`_ recorded by Gerry Jenkins to support all of the chapters in this text.

.. toctree::
   :numbered:
   :maxdepth: 3

   Introduction/toctree.rst
   AlgorithmAnalysis/toctree.rst
   BasicDS/toctree.rst
   Recursion/toctree.rst
   SortSearch/toctree.rst
   Trees/toctree.rst
   Graphs/toctree.rst
   Advanced/toctree.rst

Acknowledgements
::::::::::::::::

We are very grateful to Franklin Beedle Publishers for allowing us to
make this interactive textbook freely available. This online version is
dedicated to the memory of our first editor, Jim Leisy, who wanted us
to "change the world."

Indices and tables
::::::::::::::::::

* :ref:`genindex`
* :ref:`search`


.. raw:: html

   <div style="width: 500px; margin-left: auto; margin-right: auto;"><a rel="license" href="http://creativecommons.org/licenses/by-nc-sa/4.0/"><img alt="Creative Commons License" style="border-width:0; display:block; margin-left: auto; margin-right:auto;" src="https://i.creativecommons.org/l/by-nc-sa/4.0/88x31.png" /></a><br /><span xmlns:dct="http://purl.org/dc/terms/" href="http://purl.org/dc/dcmitype/InteractiveResource" property="dct:title" rel="dct:type">Problem Solving with Algorithms and Data Structures using Python</span> by <span xmlns:cc="http://creativecommons.org/ns#" property="cc:attributionName">Bradley N. Miller, David L. Ranum</span> is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by-nc-sa/4.0/">Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License</a>.</div>
